@@ -1,7 +1,7 @@
 /* ****************************************************************************
   This file is part of Lokalize
 
-  Copyright (C) 2007-2013 by Nick Shaforostoff <shafff@ukr.net>
+  Copyright (C) 2007-2014 by Nick Shaforostoff <shafff@ukr.net>
 
   This program is free software; you can redistribute it and/or
   modify it under the terms of the GNU General Public License as
@@ -26,12 +26,15 @@
 #include "catalog.h"
 #include "project.h"
 
-#include <kdebug.h>
-#include <klocale.h>
-
-#include <QApplication>
-#include <QFontMetrics>
+#ifndef NOKDE
 #include <kcolorscheme.h>
+#endif
+#include <klocalizedstring.h>
+
+#include <QDebug>
+#include <QApplication>
+#include <QPalette>
+#include <QFontMetrics>
 
 #define DYNAMICFILTER_LIMIT 256
 
@@ -78,7 +81,8 @@ int CatalogTreeModel::columnCount(const QModelIndex& parent) const
 
 void CatalogTreeModel::fileLoaded()
 {
-    reset();
+    beginResetModel();
+    endResetModel();
 }
 
 void CatalogTreeModel::reflectChanges(DocPosition pos)
@@ -90,11 +94,11 @@ void CatalogTreeModel::reflectChanges(DocPosition pos)
     //lazy sorting/filtering
     if (rowCount()<DYNAMICFILTER_LIMIT || m_prevChanged!=pos)
     {
-        kWarning()<<"first dataChanged emitment"<<pos.entry;
+        qWarning()<<"first dataChanged emitment"<<pos.entry;
         emit dataChanged(index(pos.entry,0),index(pos.entry,DisplayedColumnCount-1));
         if (!( rowCount()<DYNAMICFILTER_LIMIT ))
         {
-            kWarning()<<"second dataChanged emitment"<<m_prevChanged.entry;
+            qWarning()<<"second dataChanged emitment"<<m_prevChanged.entry;
             emit dataChanged(index(m_prevChanged.entry,0),index(m_prevChanged.entry,DisplayedColumnCount-1));
         }
     }
@@ -120,6 +124,7 @@ QVariant CatalogTreeModel::headerData(int section, Qt::Orientation /*orientation
         case Source:    return i18nc("@title:column Original text","Source");
         case Target:    return i18nc("@title:column Text in target language","Target");
         case Notes:     return i18nc("@title:column","Notes");
+        case Context:   return i18nc("@title:column","Context");
         case TranslationStatus: return i18nc("@title:column","Translation Status");
     }
     return QVariant();
@@ -143,6 +148,7 @@ QVariant CatalogTreeModel::data(const QModelIndex& index, int role) const
     }
     else if (role==Qt::ForegroundRole)
     {
+#ifndef NOKDE
        if (m_catalog->isBookmarked(index.row()))
        {
            static KColorScheme colorScheme(QPalette::Normal);
@@ -153,23 +159,34 @@ QVariant CatalogTreeModel::data(const QModelIndex& index, int role) const
            static KColorScheme colorScheme(QPalette::Normal);
            return colorScheme.foreground(KColorScheme::InactiveText);
        }
+#else
+       if (m_catalog->isBookmarked(index.row()))
+       {
+           return QApplication::palette().link();
+       }
+       if (m_catalog->isObsolete(index.row()))
+       {
+           return QApplication::palette().brightText();
+       }
+#endif
     }
     else if (role==Qt::UserRole)
     {
         switch (index.column())
         {
             case TranslationStatus:   return m_catalog->isApproved(index.row());
-            case Empty:     return m_catalog->isEmpty(index.row());
+            case IsEmpty:     return m_catalog->isEmpty(index.row());
             case State:     return int(m_catalog->state(index.row()));
-            case Modified:  return m_catalog->isModified(index.row());
+            case IsModified:  return m_catalog->isModified(index.row());
+            case IsPlural:  return m_catalog->isPlural(index.row());
             default:        role=Qt::DisplayRole;
         }
     }
     else if (role==StringFilterRole) //exclude UI strings
     {
-        if (index.column()>Notes)
+        if (index.column()>=TranslationStatus)
             return QVariant();
-        else if (index.column()) //>Key
+        else if (index.column()==Source || index.column()==Target)
         {
             static const DocPosition::Part parts[]={DocPosition::Source, DocPosition::Target};
             QString str=m_catalog->catalogString(DocPosition(index.row(),parts[index.column()==Target])).string;
@@ -194,6 +211,7 @@ QVariant CatalogTreeModel::data(const QModelIndex& index, int role) const
                 result+=note.content;
             return result;
         }
+        case Context: return m_catalog->context(index.row());
         case TranslationStatus:
             static QString statuses[]={i18nc("@info:status 'non-fuzzy' in gettext terminology","Ready"),
                                     i18nc("@info:status 'fuzzy' in gettext terminology","Needs review"),
@@ -214,7 +232,7 @@ CatalogTreeFilterModel::CatalogTreeFilterModel(QObject* parent)
     setFilterKeyColumn(-1);
     setFilterCaseSensitivity(Qt::CaseInsensitive);
     setFilterRole(CatalogTreeModel::StringFilterRole);
-    //setDynamicSortFilter(true);
+    setDynamicSortFilter(false);
 }
 
 void CatalogTreeFilterModel::setSourceModel(QAbstractItemModel* sourceModel)
@@ -259,14 +277,19 @@ bool CatalogTreeFilterModel::filterAcceptsRow(int source_row, const QModelIndex&
     }
     if (accepts&&bool(filerOptions&NonEmpty)!=bool(filerOptions&Empty))
     {
-        bool untr=sourceModel()->index(source_row,CatalogTreeModel::Empty,source_parent).data(Qt::UserRole).toBool();
+        bool untr=sourceModel()->index(source_row,CatalogTreeModel::IsEmpty,source_parent).data(Qt::UserRole).toBool();
         accepts=(untr==bool(filerOptions&Empty) || untr!=bool(filerOptions&NonEmpty));
     }
     if (accepts&&bool(filerOptions&Modified)!=bool(filerOptions&NonModified))
     {
-        bool modified=sourceModel()->index(source_row,CatalogTreeModel::Modified,source_parent).data(Qt::UserRole).toBool();
+        bool modified=sourceModel()->index(source_row,CatalogTreeModel::IsModified,source_parent).data(Qt::UserRole).toBool();
         accepts=(modified==bool(filerOptions&Modified) || modified!=bool(filerOptions&NonModified));
     }
+    if (accepts&&bool(filerOptions&Plural)!=bool(filerOptions&NonPlural))
+    {
+        bool modified=sourceModel()->index(source_row,CatalogTreeModel::IsPlural,source_parent).data(Qt::UserRole).toBool();
+        accepts=(modified==bool(filerOptions&Plural) || modified!=bool(filerOptions&NonPlural));
+    }
 
     // These are the possible sync options of a row:
     // * SameInSync: The sync file contains a row with the same msgid and the same msgstr.
@@ -282,9 +305,9 @@ bool CatalogTreeFilterModel::filterAcceptsRow(int source_row, const QModelIndex&
         bool isDifferent = m_mergeCatalog->isDifferent(source_row);
 
         accepts = !
-           (  isPresent && !isDifferent && !bool(filerOptions&SameInSync)      ||
-              isPresent &&  isDifferent && !bool(filerOptions&DifferentInSync) ||
-             !isPresent &&                 !bool(filerOptions&NotInSync)
+           ( (isPresent && !isDifferent && !bool(filerOptions&SameInSync))      ||
+             (isPresent &&  isDifferent && !bool(filerOptions&DifferentInSync)) ||
+            (!isPresent &&                 !bool(filerOptions&NotInSync))
            );
     }
 
